@@ -20,16 +20,10 @@
 oo_DEFINE_CLASS (SoundFrameIntoMatrixFrame, SoundFrameIntoSampledFrame)
 
 	oo_UNSAFE_BORROWED_TRANSIENT_MUTABLE_OBJECT_REFERENCE (Matrix, matrix)
-	oo_MAT (localOutput, matrix -> ny, maximumNumberOfFrames)
-	
+
 	#if oo_DECLARING
-
-		void allocateOutputFrames (void) override;  // allocates the localOutput matrix
-		
-		void saveLocalOutputFrames (void) override;
-		
-		void allocateMemoryAfterThreadsAreKnown () override;
-
+		void allocateOutputFrames ()
+			override;
 	#endif
 		
 oo_END_CLASS (SoundFrameIntoMatrixFrame)
