@@ -1,10 +1,10 @@
 /* Praat_tests.cpp
  *
- * Copyright (C) 2001-2007,2009,2011-2024 Paul Boersma
+ * Copyright (C) 2001-2007,2009,2011-2025 Paul Boersma, David Weenink 2025
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  *
  * This code is distributed in the hope that it will be useful, but
@@ -668,7 +668,7 @@ int Praat_tests (kPraatTests itest, conststring32 arg1, conststring32 arg2, cons
 		} break;
 		case kPraatTests::TIME_MULTI_THREADING: {
 			const double durationOfSound = ( n < 0 ? 5.0 : 100.0 );
-			timeMultiThreading (durationOfSound);
+			SampledIntoSampled_timeMultiThreading (durationOfSound);
 			//  Gflops is --undefined--
 		} break;
 		case kPraatTests::TIME_MEDIAN: {
